/*!
// @file		ImapWindowController.h
//
// @brief		Controller class
//
// @version		Mailit for C/C++ 1.0
//
// @author		(C) 2007 Dacons LLP.
//
// @bug			If you have problems or suggestions, please contact
//				the Online Support at: http://www.dacons.net/support
 */

#import <Cocoa/Cocoa.h>
#include <EmaiIMAP.hpp>
#include "ImapResponseHandler.hpp"
#include "ImapCallback.hpp"

@interface ImapWindowController : NSWindowController
{
    IBOutlet NSTextField *mAccount;
    IBOutlet NSTableView *mMailboxes;
    IBOutlet NSTextField *mMailServer;
    IBOutlet NSTableView *mMessages;
    IBOutlet NSSecureTextField *mPassword;
	IBOutlet NSPanel *mInputWnd;
	IBOutlet NSPanel *mMsgWnd;
	IBOutlet NSPanel *mSendMsgWnd;
	IBOutlet NSTextField *mMailboxName;
	IBOutlet NSTextField *mFrom;
	IBOutlet NSTextField *mTo;
	IBOutlet NSTextField *mSubject;
	IBOutlet NSTextField *mSubject2;
	IBOutlet NSTextView *mMsgText;
	IBOutlet NSTextField *mSendFrom;
	IBOutlet NSTextField *mSendTo;
	IBOutlet NSTextField *mSendCC;
	IBOutlet NSTextField *mSendSubject;
	IBOutlet NSTextView *mSendMsgText;
	IBOutlet NSTableView *mSendAttachments;
	IBOutlet NSTextField *mStatusText;
	IBOutlet NSTextField *mStatusPercent;
	IBOutlet NSTextField *mPort;
	IBOutlet NSButton *mUseSsl;
	IBOutlet NSButton *mExpunge;
	IBOutlet NSPopUpButton *mAuthType;
	IBOutlet NSButton *mAnotherServer;
	IBOutlet NSButton *mGetMailboxes;
	IBOutlet NSButton *mRenameMailbox;
	ImapCallback *mStatusCallback;
	ImapResponseHandler *mImapResponseHandler;
	Emai::ImapSession *mImapSession;
	NSTimer *mNoopTimer;
	NSMutableArray *mAttachmentsList;
	int mLastSelectedMailbox;
	IBOutlet NSTextField *mLicKey;
}
	/*!
	// @brief	Calls when user clicks on add folder (+) button.
    */
- (IBAction)addMailbox:(id)sender;

	/*!
	// @brief	Calls when user clicks on add message (+) button.
	 */
- (IBAction)addMessage:(id)sender;

	/*!
	// @brief	Calls when user clicks on delete folder (-) button.
	 */
- (IBAction)deleteMailbox:(id)sender;

	/*!
	// @brief	Calls when user clicks on delete message (-) button.
	 */
- (IBAction)deleteMessage:(id)sender;

	/*!
	// @brief	Calls when user clicks on Get mailboxes button.
	 */
- (IBAction)getMailboxes:(id)sender;

	/*!
	// @brief	Calls when user clicks on OK button.
	 */
- (IBAction)sheetOK:(id)sender;

	/*!
	// @brief	Calls when user clicks on Cancel button.
	 */
- (IBAction)sheetCancel:(id)sender;

	/*!
	// @brief	Calls when user clicks on expunge button.
	 */
- (IBAction)expungeMessages:(id)sender;

	/*!
	// @brief	Calls when user clicks on another server button.
	 */
- (IBAction)setAnotherServer:(id)sender;

	/*!
	// @brief	Calls when user clicks on Rename button.
	 */
- (IBAction)renameMailbox:(id)sender;

	/*!
	// @brief	Calls when user clicks on Undelete button.
	 */
- (IBAction)undeleteMessages:(id)sender;

@end
